@@ -22,7 +22,6 @@
 import logging
 from typing import List
 from typing import Optional
-from typing import Tuple
 
 from squeak.core.keys import SqueakPublicKey
 
@@ -55,17 +54,16 @@ class SqueakPeerServerHandler(object):
         self.node_settings = node_settings
         self.config = config
 
-    def handle_get_squeak_bytes(self, squeak_hash_str) -> Tuple[str, bytes]:
+    def handle_get_squeak_bytes(self, squeak_hash_str) -> bytes:
         """Return a tuple with the squeak type and the squeak bytes.
 
-        Returns: (str, bytes)
+        Returns: bytes
         """
         squeak_hash = bytes.fromhex(squeak_hash_str)
         squeak = self.squeak_controller.get_squeak(squeak_hash)
         if not squeak:
             raise NotFoundError()
-        squeak_type = 'resqueak' if squeak.is_resqueak else 'squeak'
-        return squeak_type, squeak.serialize()
+        return squeak.serialize()
 
     def handle_get_secret_key(self, squeak_hash_str) -> bytes:
         squeak_hash = bytes.fromhex(squeak_hash_str)
